#
# spec file for package pantheon-onboarding
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.onboarding
Name:           pantheon-onboarding
Version:        8.0.3
Release:        1.1
Summary:        Setting General Preferences
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/onboarding
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(pantheon-wayland-1)
Provides:       elementary-onboarding = %{version}
Obsoletes:      elementary-onboarding < %{version}

%description
Quickly change common settings on first-run.

%lang_package

%prep
%autosetup -n onboarding-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} >= 1600
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
mv %{buildroot}%{_sysconfdir}/xdg/autostart/%{appid}.desktop \
   %{buildroot}%{_distconfdir}/xdg/autostart/%{appid}.desktop
%endif

%files
%license COPYING
%doc README.md
%{_sysconfdir}/guest-session
%if 0%{?suse_version} >= 1600
%{_distconfdir}/xdg/autostart/%{appid}.desktop
%else
%{_sysconfdir}/xdg/autostart/%{appid}.desktop
%endif
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.metainfo.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Fri Dec 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.3:
  * MainWindow: center with shell protocol
  * Updated translations
* Mon Nov 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.2:
  * WelcomeView: Fix missing handler when a row activated
  * Updated translations
- update to 8.0.1:
  * AbstractOnboardingView: replace skip all with back on non-welcome
  * WelcomeView: copy links redesign from Settings
  * Update onboarding.metainfo.xml.in
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-onboarding
- remove %%suse_update_desktop_file, as it's deprecated
- mv xdg/autostart to /usr/etc
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- enable leap by using datadir/icons
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Meson: remove deprecations
  * Application: use Granite.init
  * Improve screenreader support
  * UpdatesView: add OS updates
  * Housekeeping: use elementary settings daemon
  * OnlineAccountsView: use icon shipped with System Settings
  * Replace Carousel with NavigationView
- update to 7.2.0:
  * WelcomeView: Update description
  * Add screenshot files cleanup option to Housekeeping
  * StyleView: use actual background when available
  * Meson: use gnome.post_install to compile schemas
- update to 7.1.0:
  * Use Gtk.LinkButton for AppCenter button
  * MainWindow: warn about daily builds
  * AppCenterView: make sideload more obvious and rework copy
  * EarlyAccessView: use applications-development for icon
  * Adjust layouts, spacing, and typography
  * WelcomeView: adjust button spacing, shorten title
  * WelcomeView: combine with what's new view
  * MainWindow: Only show What's New if there's something other than Early Access
  * Add GuestView
  * Redesign app icon
- update to 7.0.1:
  * Updated translations
- update to 7.0.0:
  * Add Automatic Updates view
  * Add Sunset to Sunrise to Style View
  * Updated translations
  * Updated to gtk4
- update to 6.1.0:
  * Redesign Housekeeping and add Downloads option
  * Updated translations
- update to 6.0.0:
  * Add style view
  * Add Online Accounts view
  * Remove location services view
  * Mention Sideload and Flathub
  * Updated translations
- update to 1.2.1:
  * Fix blurry icon in AppCenter
  * Updated translations
- update to 1.2.0:
  * New app icon
  * Updated translations
- update to 1.1.0:
  * Navigate with (multi-)touch gestures
  * Use new blog URL
  * Fix errors when pressing the Skip button
  * Updated translations
- switch url to actually github, obs is not the upstream url
* Thu Aug 29 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.1:
  * Clarify Location Services copy (#57)
  * No need for a null AppCenter view (#55)
  * Check for GeoClue key before creating Location Services view
    (#54)
* Wed May  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
